@@ -12,7 +12,7 @@
 
 from openstack.network import network_service
 from openstack.network.v2 import tag
-from openstack import resource2 as resource
+from openstack import resource
 
 
 class Subnet(resource.Resource, tag.TagMixin):
@@ -89,6 +89,3 @@ class Subnet(resource.Resource, tag.TagMixin):
         'use_default_subnetpool',
         type=bool
     )
-    #: A list of assocaited tags
-    #: *Type: list of tag strings*
-    tags = resource.Body('tags', type=list)
