@@ -11,52 +11,18 @@
 # under the License.
 
 """
-:class:`~openstack.profile.Profile` is the class that is used to
-define the various preferences for different services.  The preferences that
-are currently supported are service name, region, version and interface.
-The :class:`~openstack.profile.Profile` and the
-:class:`~openstack.connection.Connection` classes are the most important
-user facing classes.
-
-Examples
---------
-
-The :class:`~openstack.profile.Profile` class is constructed
-with no arguments.
-
-Set Methods
-~~~~~~~~~~~
-
-A user's preferences are set based on the service type.  Service type would
-normally be something like 'compute', 'identity', 'object-store', etc.::
-
-    from openstack import profile
-    prof = profile.Profile()
-    prof.set_name('compute', 'matrix')
-    prof.set_region(prof.ALL, 'zion')
-    prof.set_version('identity', 'v3')
-    prof.set_interface('object-store', 'internal')
-    for service in prof.get_services():
-        print(prof.get_filter(service.service_type)
-
-The resulting preference print out would look something like::
-
-    service_type=compute,region=zion,service_name=matrix
-    service_type=network,region=zion
-    service_type=database,region=zion
-    service_type=image,region=zion
-    service_type=metering,region=zion
-    service_type=orchestration,region=zion
-    service_type=object-store,interface=internal,region=zion
-    service_type=identity,region=zion,version=v3
+:class:`~openstack.profile.Profile` is deprecated. Code should use
+:class:`~openstack.config.cloud_region.CloudRegion` instead.
 """
 
 import copy
-import logging
 
-from openstack.bare_metal import bare_metal_service
-from openstack.block_store import block_store_service
-from openstack.cluster import cluster_service
+from openstack import _log
+from openstack.config import cloud_region
+from openstack.config import defaults as config_defaults
+from openstack.baremetal import baremetal_service
+from openstack.block_storage import block_storage_service
+from openstack.clustering import clustering_service
 from openstack.compute import compute_service
 from openstack.database import database_service
 from openstack import exceptions
@@ -65,15 +31,40 @@ from openstack.image import image_service
 from openstack.key_manager import key_manager_service
 from openstack.load_balancer import load_balancer_service as lb_service
 from openstack.message import message_service
-from openstack import module_loader
 from openstack.network import network_service
 from openstack.object_store import object_store_service
 from openstack.orchestration import orchestration_service
-from openstack.telemetry.alarm import alarm_service
-from openstack.telemetry import telemetry_service
+from openstack import utils
 from openstack.workflow import workflow_service
 
-_logger = logging.getLogger(__name__)
+_logger = _log.setup_logging('openstack')
+
+
+def _get_config_from_profile(profile, authenticator, **kwargs):
+    # TODO(shade) Remove this once we've shifted python-openstackclient
+    # to not use the profile interface.
+
+    region_name = None
+    for service in profile.get_services():
+        if service.region:
+            region_name = service.region
+        service_type = service.service_type
+        if service.interface:
+            key = cloud_region._make_key('interface', service_type)
+            kwargs[key] = service.interface
+        if service.version:
+            version = service.version
+            if version.startswith('v'):
+                version = version[1:]
+            key = cloud_region._make_key('api_version', service_type)
+            kwargs[key] = version
+
+    config_kwargs = config_defaults.get_defaults()
+    config_kwargs.update(kwargs)
+    config = cloud_region.CloudRegion(
+        region_name=region_name, config=config_kwargs)
+    config._auth = authenticator
+    return config
 
 
 class Profile(object):
@@ -81,6 +72,8 @@ class Profile(object):
     ALL = "*"
     """Wildcard service identifier representing all services."""
 
+    @utils.deprecated(deprecated_in="0.10.0", removed_in="1.0",
+                      details="Use openstack.config instead")
     def __init__(self, plugins=None):
         """User preference for each service.
 
@@ -93,10 +86,10 @@ class Profile(object):
         """
         self._services = {}
 
-        self._add_service(alarm_service.AlarmService(version="v2"))
-        self._add_service(bare_metal_service.BareMetalService(version="v1"))
-        self._add_service(block_store_service.BlockStoreService(version="v2"))
-        self._add_service(cluster_service.ClusterService(version="v1"))
+        self._add_service(baremetal_service.BaremetalService(version="v1"))
+        self._add_service(
+            block_storage_service.BlockStorageService(version="v2"))
+        self._add_service(clustering_service.ClusteringService(version="v1"))
         self._add_service(compute_service.ComputeService(version="v2"))
         self._add_service(database_service.DatabaseService(version="v1"))
         self._add_service(identity_service.IdentityService(version="v3"))
@@ -109,12 +102,8 @@ class Profile(object):
             object_store_service.ObjectStoreService(version="v1"))
         self._add_service(
             orchestration_service.OrchestrationService(version="v1"))
-        self._add_service(telemetry_service.TelemetryService(version="v2"))
         self._add_service(workflow_service.WorkflowService(version="v2"))
 
-        if plugins:
-            for plugin in plugins:
-                self._load_plugin(plugin)
         self.service_keys = sorted(self._services.keys())
 
     def __repr__(self):
@@ -124,18 +113,8 @@ class Profile(object):
         serv.interface = None
         self._services[serv.service_type] = serv
 
-    def _load_plugin(self, namespace):
-        """Load a service plugin.
-
-        :param str namespace: Entry point namespace
-        """
-        services = module_loader.load_service_plugins(namespace)
-        for service_type in services:
-            if service_type in self._services:
-                _logger.debug("Overriding %s with %s", service_type,
-                              services[service_type])
-            self._add_service(services[service_type])
-
+    @utils.deprecated(deprecated_in="0.10.0", removed_in="1.0",
+                      details="Use openstack.config instead")
     def get_filter(self, service):
         """Get a service preference.
 
@@ -162,6 +141,8 @@ class Profile(object):
         for service in self._get_services(service):
             setattr(self._get_filter(service), attr, value)
 
+    @utils.deprecated(deprecated_in="0.10.0", removed_in="1.0",
+                      details="Use openstack.config instead")
     def get_services(self):
         """Get a list of all the known services."""
         services = []
@@ -169,6 +150,8 @@ class Profile(object):
             services.append(service)
         return services
 
+    @utils.deprecated(deprecated_in="0.10.0", removed_in="1.0",
+                      details="Use openstack.config instead")
     def set_name(self, service, name):
         """Set the desired name for the specified service.
 
@@ -177,6 +160,8 @@ class Profile(object):
         """
         self._setter(service, "service_name", name)
 
+    @utils.deprecated(deprecated_in="0.10.0", removed_in="1.0",
+                      details="Use openstack.config instead")
     def set_region(self, service, region):
         """Set the desired region for the specified service.
 
@@ -185,6 +170,8 @@ class Profile(object):
         """
         self._setter(service, "region", region)
 
+    @utils.deprecated(deprecated_in="0.10.0", removed_in="1.0",
+                      details="Use openstack.config instead")
     def set_version(self, service, version):
         """Set the desired version for the specified service.
 
@@ -193,6 +180,8 @@ class Profile(object):
         """
         self._get_filter(service).version = version
 
+    @utils.deprecated(deprecated_in="0.10.0", removed_in="1.0",
+                      details="Use openstack.config instead")
     def set_api_version(self, service, api_version):
         """Set the desired API micro-version for the specified service.
 
@@ -201,6 +190,8 @@ class Profile(object):
         """
         self._setter(service, "api_version", api_version)
 
+    @utils.deprecated(deprecated_in="0.10.0", removed_in="1.0",
+                      details="Use openstack.config instead")
     def set_interface(self, service, interface):
         """Set the desired interface for the specified service.
 
